@@ -105,12 +105,13 @@ public:
     // by Deepin Window Manager
     static bool hasBlurWindow();
     static bool hasComposite();
+    static QString windowManagerName();
     static bool blurWindowBackground(const quint32 WId, const QVector<BlurArea> &areas);
     static bool blurWindowBackgroundByPaths(const quint32 WId, const QList<QPainterPath> &paths);
     static bool blurWindowBackgroundByImage(const quint32 WId, const QRect &blurRect, const QImage &maskImage);
     static void clearWindowBlur(const quint32 WId);
 
-    static quint32 getWorkspaceForWindow(quint32 WId);
+    static qint32 getWorkspaceForWindow(quint32 WId);
     static QVector<quint32> getWindows();
     static QVector<quint32> getCurrentWorkspaceWindows();
 
